@@ -112,6 +112,13 @@ def _validate_group(ctx, param, value):
     type=str,
     callback=_validate_group,
 )
+@click.option(
+    "--allow-test-before-build",
+    "is_allow_test_before_build",
+    help="",
+    is_flag=True,
+    hidden=True,
+)
 @click.pass_context
 def tests(
     context: click.core.Context,
@@ -121,9 +128,10 @@ def tests(
     post_chunk: int,
     subsetting_id: str,
     flavor,
-    no_base_path_inference,
-    report_paths,
-    group,
+    no_base_path_inference: bool,
+    report_paths: bool,
+    group: str,
+    is_allow_test_before_build: bool,
 ):
     logger = Logger()
 
@@ -243,6 +251,7 @@ def tests(
             self.base_path = base_path
             self.dry_run = dry_run
             self.no_base_path_inference = no_base_path_inference
+            self.is_allow_test_before_build = is_allow_test_before_build
 
         def make_file_path_component(self, filepath) -> TestPathComponent:
             """Create a single TestPathComponent from the given file path"""
@@ -254,7 +263,7 @@ def tests(
             ctime = datetime.datetime.fromtimestamp(
                 os.path.getctime(junit_report_file))
 
-            if self.check_timestamp and ctime.timestamp() < record_start_at.timestamp():
+            if not self.is_allow_test_before_build and (self.check_timestamp and ctime.timestamp() < record_start_at.timestamp()):
                 format = "%Y-%m-%d %H:%M:%S"
                 logger.warning("skip: {} is too old to report. start_record_at: {} file_created_at: {}".format(
                     junit_report_file, record_start_at.strftime(format), ctime.strftime(format)))
