@@ -119,6 +119,12 @@ from .test_path_writer import TestPathWriter
     help="outputs the exclude test list. Switch the subset and rest.",
     is_flag=True,
 )
+@click.option(
+    "--ignore-flaky-tests-above",
+    "ignore_flaky_tests_above",
+    help='Ignore flaky tests above the value set by this option.You can confirm flaky scores in WebApp',
+    type=click.FloatRange(min=0, max=1.0),
+)
 @click.pass_context
 def subset(
     context: click.core.Context,
@@ -136,6 +142,7 @@ def subset(
     is_observation: bool,
     is_get_tests_from_previous_sessions: bool,
     is_output_exclusion_rules: bool,
+    ignore_flaky_tests_above: Optional[float],
 ):
 
     if is_observation and is_get_tests_from_previous_sessions:
@@ -301,11 +308,23 @@ def subset(
                     "type": "subset-by-confidence",
                     "percentage": confidence
                 }
+            else:
+                payload['useServerSideOptimizationTarget'] = True
+
+            if ignore_flaky_tests_above:
+                payload["dropFlakinessThreshold"] = ignore_flaky_tests_above
 
             return payload
 
         def run(self):
             """called after tests are scanned to compute the optimized order"""
+            if not is_get_tests_from_previous_sessions and len(self.test_paths) == 0:
+                click.echo(
+                    click.style(
+                        "ERROR: subset candidates are empty. Please set subset candidates or use `--get-tests-from-previous-sessions` option",  # noqa E501
+                        fg="red"),
+                    err=True)
+                exit(1)
 
             # When Error occurs, return the test name as it is passed.
             original_subset = self.test_paths
@@ -336,8 +355,8 @@ def subset(
 
                     original_subset = res.json().get("testPaths", [])
                     original_rests = res.json().get("rest", [])
-                    subset_id = res.json()["subsettingId"]
-                    summary = res.json()["summary"]
+                    subset_id = res.json().get("subsettingId", 0)
+                    summary = res.json().get("summary", {})
                     is_brainless = res.json().get("isBrainless", False)
                     is_observation = res.json().get("isObservation", False)
 
@@ -346,6 +365,7 @@ def subset(
                         raise e
                     else:
                         click.echo(e, err=True)
+
                     click.echo(click.style(
                         "Warning: the service failed to subset. Falling back to running all tests", fg='yellow'),
                         err=True)
