@@ -73,6 +73,64 @@ class RawTest(CliTestCase):
                 'testcase=FooTest.Foo',
             ]) + '\n')
 
+    @responses.activate
+    @mock.patch.dict(os.environ, {"LAUNCHABLE_TOKEN": CliTestCase.launchable_token})
+    def test_subset_get_tests_from_previous_sessions(self):
+        responses.replace(
+            responses.POST,
+            "{}/intake/organizations/{}/workspaces/{}/subset".format(
+                get_base_url(), self.organization, self.workspace),
+            json={
+                "testPaths": [
+                    [{'type': 'testcase', 'name': 'FooTest.Bar'}],
+                    [{'type': 'testcase', 'name': 'FooTest.Foo'}],
+                ],
+                "testRunner": "raw",
+                "rest": [
+                    [{'type': 'testcase', 'name': 'FooTest.Baz'}],
+                ],
+                "subsettingId": 456,
+                "summary": {
+                    "subset": {"candidates": 4, "duration": 4, "rate": 90},
+                    "rest": {"candidate": 1, "duration": 0, "rate": 0}
+                },
+                "isBrainless": False
+            },
+            status=200)
+
+        # emulate launchable record build
+        write_build(self.build_name)
+
+        # Don't use with for Windows environment
+        rest = tempfile.NamedTemporaryFile(mode="+w", encoding="utf-8", delete=False)
+        result = self.cli(
+            'subset',
+            '--target',
+            '10%',
+            '--get-tests-from-previous-sessions',
+            "--rest", rest.name,
+            'raw',
+            mix_stderr=False)
+        self.assertEqual(result.exit_code, 0)
+
+        # Check request body
+        payload = json.loads(gzip.decompress(responses.calls[1].request.body).decode())
+        self.assert_json_orderless_equal(payload, {
+            'testPaths': [],
+            'testRunner': 'raw',
+            'session': {'id': str(self.session_id)},
+            "goal": {"type": "subset-by-percentage", "percentage": 0.1},
+            "ignoreNewTests": False,
+            "getTestsFromPreviousSessions": True,
+        })
+
+        # Check outputs
+        self.assertEqual(result.stdout, "testcase=FooTest.Bar\ntestcase=FooTest.Foo" + "\n")
+        self.assertEqual(rest.read(), "testcase=FooTest.Baz")
+
+        rest.close()
+        os.unlink(rest.name)
+
     @responses.activate
     @mock.patch.dict(os.environ, {"LAUNCHABLE_TOKEN": CliTestCase.launchable_token})
     def test_record_tests(self):
@@ -118,7 +176,56 @@ class RawTest(CliTestCase):
                         'type': 'case',
                     },
                 ],
-                "testRunner": "raw"
+                "testRunner": "raw",
+                "group": ""
+            })
+
+    @responses.activate
+    @mock.patch.dict(os.environ, {"LAUNCHABLE_TOKEN": CliTestCase.launchable_token})
+    def test_record_tests_junit_xml(self):
+        with tempfile.TemporaryDirectory() as tempdir:
+            test_path_file = os.path.join(tempdir, 'tests.xml')
+            with open(test_path_file, 'w') as f:
+                f.write('\n'.join([
+                    '<?xml version="1.0" encoding="UTF-8"?>',
+                    '<testsuites name="test_suite_name1" tests="1" failures="0" errors="0" time="10.123">',
+                    '  <testsuite name="test_suite_name2" errors="0" failures="0" skipped="0" timestamp="2021-10-05T12:34:00" time="10.123" tests="1">',   # noqa: E501
+                    '    <testcase classname="test_class_name" name="test_case_name" time="10.123">',
+                    '    </testcase>',
+                    '  </testsuite>',
+                    '</testsuites>',
+                ]) + '\n')
+
+            # emulate launchable record build
+            write_build(self.build_name)
+
+            result = self.cli('record', 'tests', 'raw', test_path_file, mix_stderr=False)
+            if result.exit_code != 0:
+                self.assertEqual(
+                    result.exit_code,
+                    0,
+                    "Exit code is not 0. The output is\n" + result.output + "\n" + result.stderr)
+
+            # Check request body
+            payload = json.loads(gzip.decompress(responses.calls[2].request.body).decode())
+            self.assert_json_orderless_equal(payload, {
+                'events': [
+                    {
+                        'testPath': [
+                            {'type': 'class', 'name': 'test_class_name'},
+                            {'type': 'testcase', 'name': 'test_case_name'},
+                        ],
+                        'duration': 10.123,
+                        'status': 1,
+                        'stdout': '',
+                        'stderr': '',
+                        'created_at': '2021-10-05T12:34:00',
+                        'data': None,
+                        'type': 'case',
+                    },
+                ],
+                "testRunner": "raw",
+                "group": ""
             })
 
     @responses.activate
